# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-22 21:16
from __future__ import unicode_literals

import calaccess_raw
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('calaccess_raw', '0008_auto_20160707_0518'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawdataversion',
            name='clean_zip_archive',
            field=models.FileField(blank=True, help_text='An archive zip of cleaned (and error log) files', max_length=255, upload_to=calaccess_raw.archive_directory_path, verbose_name='cleaned files zip archive'),
        ),
    ]
