# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-08-01 20:39
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('calaccess_raw', '0013_auto_20160729_0506'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='rawdatacommand',
            name='called_by',
        ),
        migrations.RemoveField(
            model_name='rawdatacommand',
            name='version',
        ),
        migrations.DeleteModel(
            name='RawDataCommand',
        ),
    ]
